import * as pj from 'projen';

const CDK_V1_VERSION = '1.200.0'; // Keep an older version for compatibility when consuming this library with older CDK version
const CDK_V2_VERSION = '2.83.1'; // just for pipeline def in infrastructure

const project = new pj.awscdk.AwsCdkConstructLibrary({
  name: '@rioclaid/cdk-constructs',
  description: 'CDK constructs to build RIO flavored CI/CD pipeline in AWS.',
  repositoryUrl: 'https://collaboration.msi.audi.com/stash/scm/riodev/cdk-constructs.git',

  author: 'TB Digital Services GmbH',
  authorOrganization: true,
  authorAddress: 'https://rio.cloud/',

  defaultReleaseBranch: 'master',
  packageManager: pj.javascript.NodePackageManager.NPM,
  docgen: false,
  projenrcTs: true,
  catalog: { announce: false },

  cdkVersion: CDK_V1_VERSION,
  cdkDependenciesAsDeps: false,
  cdkAssertions: true,
  cdkVersionPinning: true,

  // exclude: ['infrastructure', 'cdk.out'],
  cdkDependencies: [
    '@aws-cdk/aws-certificatemanager',
    '@aws-cdk/aws-codebuild',
    '@aws-cdk/aws-codepipeline',
    '@aws-cdk/aws-codepipeline-actions',
    '@aws-cdk/aws-cloudformation',
    '@aws-cdk/aws-cloudfront',
    '@aws-cdk/aws-cloudfront-origins',
    '@aws-cdk/aws-cloudwatch',
    '@aws-cdk/aws-cloudwatch-actions',
    '@aws-cdk/aws-docdb',
    '@aws-cdk/aws-dynamodb',
    '@aws-cdk/aws-ec2',
    '@aws-cdk/aws-ecr',
    '@aws-cdk/aws-ecs',
    '@aws-cdk/aws-elasticloadbalancingv2',
    '@aws-cdk/aws-iam',
    '@aws-cdk/aws-kms',
    '@aws-cdk/aws-lambda',
    '@aws-cdk/aws-lambda-nodejs',
    '@aws-cdk/aws-logs',
    '@aws-cdk/aws-rds',
    '@aws-cdk/aws-route53',
    '@aws-cdk/aws-route53-targets',
    '@aws-cdk/aws-s3',
    '@aws-cdk/aws-sns',
    '@aws-cdk/aws-ssm',
    '@aws-cdk/core',
    '@aws-cdk/pipelines',
    '@aws-cdk/custom-resources',
  ],
  peerDeps: ['projen'],
  deps: ['projen'],
  devDeps: [
    '@types/fs-extra@^8',
    '@types/js-yaml',
    'esbuild',
    'pre-commit',
    'projen',
    'standard-version',
  ],

  bundledDeps: ['fs-extra', 'js-yaml'],

  compat: true,
  github: false,
  releaseWorkflow: false,

  gitignore: ['.idea', '.vscode'],
});

project.addFields({
  'standard-version': {
    commitUrlFormat:
      'https://collaboration.msi.audi.com/stash/projects/RIODEV/repos/cdk-constructs/commits/{{hash}}',
    compareUrlFormat:
      '{{host}}/stash/projects/RIODEV/repos/cdk-constructs/compare/commits?targetBranch=refs%2Ftags%2F{{previousTag}}&sourceBranch=refs%2Ftags%2F{{currentTag}}',
    issueUrlFormat: 'https://collaboration.msi.audi.com/jira/browse/{{id}}',
  },
});

const bumpTask = project.addTask('bump', {
  description:
    'Commits a bump to the package version based on conventional commits',
  condition: '! git log --oneline -1 | grep -q "chore(release):"',
});
bumpTask.exec('standard-version');

const release = project.addTask('release', {
  description: 'Bumps version & push to master',
  condition: '! git log --oneline -1 | grep -q "chore(release):"',
});
release.spawn(bumpTask);
release.exec('git push --follow-tags origin master');

project.addExcludeFromCleanup('infrastructure/**');
project.addExcludeFromCleanup('**/*.snap');
project.jest!.addIgnorePattern('infrastructure');
project.gitignore.exclude('__entrypoint__.js', 'cdk.out');
project.npmignore!.exclude('examples', 'infrastructure');
project.synth();

const infraProject = new pj.awscdk.AwsCdkTypeScriptApp({
  parent: project,

  name: 'infrastructure',
  defaultReleaseBranch: 'master',
  packageManager: pj.javascript.NodePackageManager.NPM,

  cdkVersion: CDK_V2_VERSION,

  outdir: './infrastructure',

  allowLibraryDependencies: false,
  github: false,
  releaseWorkflow: false,
});

infraProject.synth();
