import * as cdk from '@aws-cdk/core';
/**
 * @stability stable
 */
export interface KafkaEventSpecProps {
    /**
     * @stability stable
     */
    readonly source: KafkaEventSpecSource;
}
/**
 * Construct to provide an event specification for a Kafka topic and upload it to the central event store.
 *
 * @stability stable
 */
export declare class KafkaEventSpec extends cdk.Construct {
    /**
     * @stability stable
     */
    constructor(scope: cdk.Construct, id: string, props: KafkaEventSpecProps);
}
/**
 * Wrapper class for the event spec itself to support providing it via file or inline string.
 *
 * @see https://collaboration.msi.audi.com/stash/projects/RSEVTBU/repos/topic-creation-example for
 * further information about the yaml spec.
 * @stability stable
 */
export declare class KafkaEventSpecSource {
    private spec;
    /**
     * Helper method to create a KafkaEventSpecSource by loading spec from a (UTF-8 encoded) yaml file.
     *
     * @param filename the filename of the event specification file.
     * @returns a KafkaEventSpecSource
     * @stability stable
     */
    static fromYamlFile(filename: string): KafkaEventSpecSource;
    /**
     * Helper method to create a KafkaEventSpecSource from an inline yaml string.
     *
     * @param spec as yaml formatted string.
     * @returns a KafkaEventSpecSource
     * @stability stable
     */
    static fromYamlString(spec: string): KafkaEventSpecSource;
    private static parseYamlSpec;
    private static isKafkaEventSpecification;
    private static determineEventNameFromSpecification;
    private static removeYamlFileEnding;
    /**
     * @stability stable
     */
    readonly eventName: string;
    private constructor();
    /**
     * @returns the message base64 encoded spec as expected by the event store
     * @stability stable
     */
    toSnsMessage(): string;
}
