import * as codepipeline from '@aws-cdk/aws-codepipeline';
import * as cdk from '@aws-cdk/core';
import * as pipelines from '@aws-cdk/pipelines';
/**
 * @stability stable
 */
export interface RioSecretsDeployActionProps {
    /**
     * Source artifact of the pipeline.
     *
     * @stability stable
     */
    readonly sourceArtifact: codepipeline.Artifact;
    /**
     * Path to secrets file containing encrypted secrets.
     *
     * @default Looks for file under 2 paths with the following priority:
     * 1. ./infrastructure/src/secrets/secrets.yaml followed by path
     * 2. ./src/secrets/secrets.yaml
     * @stability stable
     */
    readonly secretsFilePath?: string;
}
/**
 * @stability stable
 */
export declare class RioSecretsDeployAction extends pipelines.ShellScriptAction {
    /**
     * Creates and attaches a codebuild project to the pipeline which looks for secrets.yaml under first ./infrastructure/src/secrets and then ./src/secrets. The secrets are then uploaded to SSM and Secrets Manager according to the data in secrets.yaml The Format of secrets file should be like the following example in yaml:.
     *
     * ---
     * SSM:
     *
     *          /config/application/secret: password
     *
     *          /config/application2/secret: password
     *
     * SecretsManager:
     *
     *          plain_text_secret: value
     *
     *          json_secret:
     *
     *              key1: value1
     *
     *              key2: value2
     *
     * @stability stable
     */
    constructor(scope: cdk.Construct, props: RioSecretsDeployActionProps);
}
/**
 * @stability stable
 */
export interface RioSecretsDeployStepProps {
    /**
     * Points to CodePipeline source step.
     *
     * @stability stable
     */
    readonly input: pipelines.CodePipelineSource;
    /**
     * Path to secrets file containing encrypted secrets.
     *
     * @default Looks for file under 2 paths with the following priority:
     * 1. ./infrastructure/src/secrets/secrets.yaml followed by path
     * 2. ./src/secrets/secrets.yaml
     * @stability stable
     */
    readonly secretsFilePath?: string;
}
/**
 * @stability stable
 */
export declare class RioSecretsDeployStep extends pipelines.CodeBuildStep {
    /**
     * Creates and attaches a codebuild project to the pipeline which looks for secrets.yaml under first ./infrastructure/src/secrets and then ./src/secrets. The secrets are then uploaded to SSM and Secrets Manager according to the data in secrets.yaml The Format of secrets file should be like the following example in yaml:.
     *
     * ---
     * SSM:
     *
     *          /config/application/secret: password
     *
     *          /config/application2/secret: password
     *
     * SecretsManager:
     *
     *          plain_text_secret: value
     *
     *          json_secret:
     *
     *              key1: value1
     *
     *              key2: value2
     *
     * @stability stable
     */
    constructor(scope: cdk.Construct, id: string, props: RioSecretsDeployStepProps);
}
