import * as pj from 'projen';
/**
 * @experimental
 */
export interface PackageRule {
    /**
     * (experimental) Package names to match.
     *
     * @experimental
     */
    readonly matchPackageNames?: string[];
    /**
     * (experimental) A version range or regex pattern capturing allowed versions for dependencies.
     *
     * @experimental
     */
    readonly allowedVersions?: string;
}
/**
 * @experimental
 */
export interface RenovateOptions {
    /**
     * (experimental) Times of day/week to limit branch creation to.
     *
     * Ref: https://docs.renovatebot.com/configuration-options/#schedule
     *
     * @default 'run anytime'
     * @experimental
     */
    readonly schedule?: string[];
    /**
     * (experimental) Skip any package file whose path matches one of these.
     *
     * Can be a string or glob pattern.
     * Ref: https://docs.renovatebot.com/configuration-options/#ignorepaths
     *
     * @default 'nothing is ignored'
     * @experimental
     */
    readonly ignorePaths?: string[];
    /**
     * (experimental) Dependencies to ignore.
     *
     * Wildcards are not supported!
     * Ref: https://docs.renovatebot.com/configuration-options/#ignoredeps
     *
     * @default none
     * @experimental
     */
    readonly ignoreDeps?: string[];
    /**
     * (experimental) packageRules is a powerful feature that lets you apply rules to individual packages or to groups of packages using regex pattern matching.
     *
     * Ref: https://docs.renovatebot.com/configuration-options/#packagerules
     *
     * @default none
     * @experimental
     */
    readonly packageRules?: PackageRule[];
}
/**
 * (experimental) (experimental) Defines Renovate configuration for node projects.
 *
 * Since module versions are managed in projen, the versioning strategy will be
 * configured to "lockfile-only" which means that only updates that can be done
 * on the lockfile itself will be proposed.
 *
 * @experimental
 */
export declare class Renovate extends pj.Component {
    /**
     * (experimental) The raw renovate configuration.
     *
     * @see https://docs.renovatebot.com/configuration-options
     * @experimental
     */
    readonly config: any;
    /**
     * @experimental
     */
    constructor(project: pj.Project, renovateConfigPath: string, _options?: RenovateOptions);
}
