import * as ec2 from '@aws-cdk/aws-ec2';
import * as elbv2 from '@aws-cdk/aws-elasticloadbalancingv2';
import * as route53 from '@aws-cdk/aws-route53';
import * as cdk from '@aws-cdk/core';
/**
 * @stability stable
 */
export interface RioLoadBalancerProps {
    /**
     * The VPC network to place the load balancer in.
     *
     * @stability stable
     */
    readonly vpc: ec2.IVpc;
    /**
     * The hosted zone in which to the Route53 record should be created.
     *
     * @stability stable
     */
    readonly hostedZone: route53.IHostedZone;
    /**
     * The service name which is used to build the domain name (serviceName.hostedZone).
     *
     * @stability stable
     */
    readonly serviceName: string;
}
/**
 * Creates a secure application load balancer with certificate and Route53 ARecord.
 *
 * @stability stable
 */
export declare class RioLoadBalancer extends cdk.Construct {
    /**
     * @stability stable
     */
    readonly loadbalancer: elbv2.ApplicationLoadBalancer;
    /**
     * @stability stable
     */
    readonly listener: elbv2.ApplicationListener;
    /**
     * @stability stable
     */
    constructor(scope: cdk.Construct, id: string, props: RioLoadBalancerProps);
}
