import * as cdk from '@aws-cdk/core';
import { RioAwsCdkTypeScriptApp } from './projen/rio-aws-cdk-typescript-app';
/** Checks if the given feature is enabled or not.
 *
 * The toggle configuration is stored in context section of cdk.json file.
 * It returns true if the value is 'true'. All other values are interpreted as 'false'.
 * If no toggle is found, it returns the given fallback (default is false);
 *
 * The key of cdk.json context should include the ticket number.
 *
 * Example cdk.json
 * {
 *    context: {
 *      "rioclaid-1234-awesomeFeatureToggle": "true"
 *    }
 * }
 *
 * @param context Either the projen project or a cdk construct. Used to look up the cdk.json config.
 * @param toggleName Name of the feature toggle. (example: rioclaid-1234-awesomeFeatureToggle)
 * @param fallback Default return value if no configuration for the toggle exist.
 */
export declare function isToggleEnabled(context: RioAwsCdkTypeScriptApp | cdk.Construct, toggleName: string, fallback?: boolean): boolean;
