import * as elbv2 from '@aws-cdk/aws-elasticloadbalancingv2';
import * as cdk from '@aws-cdk/core';
import { IWatchful } from './watchful';
/**
 * Options for defining alarms.
 *
 * @stability stable
 */
export interface WatchApplicationLoadBalancerOptions {
    /**
     * Number of allowed rejected connections per minute.
     *
     * @default 0
     * @stability stable
     */
    readonly rejectedConnectionPerMinuteThreshold?: number;
    /**
     * Number of allowed HTTP 5xx requests per minute.
     *
     * @default 0
     * @stability stable
     */
    readonly http5xxPerMinuteThreshold?: number;
}
/**
 * Properties for defining a WatchApplicationLoadBalancer.
 *
 * @stability stable
 */
export interface WatchApplicationLoadBalancerProps extends WatchApplicationLoadBalancerOptions {
    /**
     * The reference to IWatchful class.
     *
     * Used internally.
     *
     * @stability stable
     */
    readonly watchful: IWatchful;
    /**
     * The application load balancer that should be watched.
     *
     * [disable-awslint:ref-via-interface]
     *
     * @stability stable
     */
    readonly alb: elbv2.ApplicationLoadBalancer;
}
/**
 * A Construct which creates the following alarms for application load balancers:.
 *
 * - rejected connections
 * - http-code 5xx
 *
 * @stability stable
 */
export declare class WatchApplicationLoadBalancer extends cdk.Construct {
    private readonly watchful;
    private readonly alb;
    /**
     * @stability stable
     */
    constructor(scope: cdk.Construct, id: string, props: WatchApplicationLoadBalancerProps);
    private createRejectedConnectionMonitor;
    private createHttpCode5xxMonitor;
}
