import * as cdk from '@aws-cdk/core';
import { MetricAlarmProps } from './metric-alarm';
/**
 * Interface for DataDogMonitor implementation.
 *
 * @stability stable
 */
export interface DataDogMetricAlarmProps extends MetricAlarmProps {
    /**
     * Service token which points to the DataDog Monitor custom resource lambda or sns topic.
     *
     * @stability stable
     */
    readonly serviceToken: string;
    /**
     * The service name used to name the montors (in datadog-integration).
     *
     * @stability stable
     */
    readonly serviceName: string;
    /**
     * The name of DataDog's OpsGenie integration.
     *
     * Used to automatically create OpsGenie alarms for the created DataDog Monitor.
     *
     * @stability stable
     */
    readonly dataDogOpsGenieIntegrationName: string;
}
/**
 * A wrapper for a custom resource that creates a DataDog Monitor.
 *
 * To use this construct, the DataDog integration needs to be installed.
 *
 * @stability stable
 */
export declare class DataDogMetricAlarm extends cdk.Construct {
    private serviceToken;
    /**
     * @stability stable
     */
    constructor(scope: cdk.Construct, id: string, props: DataDogMetricAlarmProps);
    /**
     * Helper function to convert a generic alarm into a DataDog query string.
     *
     * @stability stable
     */
    alarmToDataDogQuery(alarm: MetricAlarmProps): string;
}
