import * as docdb from '@aws-cdk/aws-docdb';
import * as cdk from '@aws-cdk/core';
import { IWatchful } from './watchful';
/**
 * Options for defining alarms.
 *
 * @stability stable
 */
export interface WatchDocDbClusterOptions {
    /**
     * Threshold of database cpu utilization.
     *
     * @default 80
     * @stability stable
     */
    readonly cpuUtilizationThreshold?: number;
    /**
     * Minimum database freeable memory in bytes.
     *
     * @default 64000000 (64 Megabyte)
     * @stability stable
     */
    readonly freeableMemoryThresholdInByte?: number;
    /**
     * Threshold of database swap usage.
     *
     * @default 256000000 (256 Megabyte)
     * @stability stable
     */
    readonly swapUsageThresholdInByte?: number;
    /**
     * Minimum database free local storage space.
     *
     * @default 2000000000 (2 Gigabyte)
     * @stability stable
     */
    readonly freeLocalStorageInByte?: number;
}
/**
 * Properties for defining a WatchDocDbCluster.
 *
 * @stability stable
 */
export interface WatchDocDbClusterProps extends WatchDocDbClusterOptions {
    /**
     * The reference to IWatchful class.
     *
     * Used internally.
     *
     * @stability stable
     */
    readonly watchful: IWatchful;
    /**
     * The DocDB cluster that should be watched.
     *
     * [disable-awslint:ref-via-interface]
     *
     * @stability stable
     */
    readonly docDb: docdb.DatabaseCluster;
}
/**
 * A Construct which creates the following alarms for DocumentDb clusters:.
 *
 * - freeable memory
 * - swap usage
 * - free local storage
 *
 * @stability stable
 */
export declare class WatchDocDbCluster extends cdk.Construct {
    private readonly watchful;
    private readonly docDb;
    /**
     * @stability stable
     */
    constructor(scope: cdk.Construct, id: string, props: WatchDocDbClusterProps);
    private createCpuUtilizationTooHighAlarm;
    private createFreeableMemoryTooLowAlarm;
    private createSwapUsageTooHighAlarm;
    private createFreeLocalStorageTooLowAlarm;
}
