import * as dynamodb from '@aws-cdk/aws-dynamodb';
import * as cdk from '@aws-cdk/core';
import { IWatchful } from './watchful';
/**
 * Options for defining alarms.
 *
 * @stability stable
 */
export interface WatchDynamoDbTableOptions {
    /**
     * Threshold of read throttle events.
     *
     * @default 1
     * @stability stable
     */
    readonly readThrottleEventsThreshold?: number;
    /**
     * Threshold of write throttle events.
     *
     * @default 1
     * @stability stable
     */
    readonly writeThrottleEventsThreshold?: number;
    /**
     * Threshold of throttled requests events.
     *
     * @default 1
     * @stability stable
     */
    readonly throttledRequestsEventsThreshold?: number;
    /**
     * Threshold of user errors.
     *
     * @default 1
     * @stability stable
     */
    readonly userErrorsThreshold?: number;
    /**
     * Threshold of system errors.
     *
     * @default 1
     * @stability stable
     */
    readonly systemErrorsThreshold?: number;
}
/**
 * Properties for defining a WatchDynamoDbTable.
 *
 * @stability stable
 */
export interface WatchDynamoDbTableProps extends WatchDynamoDbTableOptions {
    /**
     * The reference to IWatchful class.
     *
     * Used internally.
     *
     * @stability stable
     */
    readonly watchful: IWatchful;
    /**
     * The DynamoDb table that should be watched.
     *
     * [disable-awslint:ref-via-interface]
     *
     * @stability stable
     */
    readonly dynamoDbTable: dynamodb.Table;
}
/**
 * A Construct which creates the following alarms for DynamoDb tables:.
 *
 * - read throttles
 * - write throttles
 * - throttled requests
 * - user errors
 * - system errors
 *
 * @stability stable
 */
export declare class WatchDynamoDbTable extends cdk.Construct {
    private readonly watchful;
    private readonly dynamoDb;
    /**
     * @stability stable
     */
    constructor(scope: cdk.Construct, id: string, props: WatchDynamoDbTableProps);
    private createReadThrottleEventsAlarm;
    private createWriteThrottleEventsAlarm;
    private createThrottledRequestsEventsAlarm;
}
