import * as ecs from '@aws-cdk/aws-ecs';
import * as cdk from '@aws-cdk/core';
import { IWatchful } from './watchful';
/**
 * Options for defining alarms.
 *
 * @stability stable
 */
export interface WatchEcsServiceOptions {
    /**
     * Threshold for the cpu utilization alarm as percentage.
     *
     * @default 80
     * @stability stable
     */
    readonly cpuUtilizationThresholdPercent?: number;
    /**
     * Threshold for the memory utilization alarm as percentage.
     *
     * @default 95
     * @stability stable
     */
    readonly memoryUtilizationThresholdPercent?: number;
}
/**
 * Properties for defining a WatchEcsService.
 *
 * @stability stable
 */
export interface WatchEcsServiceProps extends WatchEcsServiceOptions {
    /**
     * The reference to IWatchful class.
     *
     * Used internally.
     *
     * @stability stable
     */
    readonly watchful: IWatchful;
    /**
     * The ECS service that should be watched.
     *
     * [disable-awslint:ref-via-interface]
     *
     * @stability stable
     */
    readonly service: ecs.BaseService;
}
/**
 * A Construct which creates default alarms for ECS services. A Construct which creates the following alarms for ECS services:.
 *
 * - cpu utilization
 * - memory utilization
 * - error log alert
 *
 * @stability stable
 */
export declare class WatchEcsService extends cdk.Construct {
    private readonly watchful;
    private readonly service;
    /**
     * @stability stable
     */
    constructor(scope: cdk.Construct, id: string, props: WatchEcsServiceProps);
    private createLogErrorMonitor;
    private createCpuUtilizationMonitor;
    private createMemoryUtilizationMonitor;
}
