import * as cw from '@aws-cdk/aws-cloudwatch';
/**
 * An interface to define a generic alarm that can be used in DataDog as well as in CloudWatch.
 *
 * @stability stable
 */
export interface MetricAlarmProps {
    /**
     * The CloudWatch metric used as source for the alarm.
     *
     * @stability stable
     */
    readonly metric: cw.Metric;
    /**
     * Description for the alarm.
     *
     * @stability stable
     */
    readonly alarmDescription: string;
    /**
     * The value against which the specified statistic is compared.
     *
     * @stability stable
     */
    readonly threshold: number;
    /**
     * Comparison to use to check if metric is breaching.
     *
     * @default GreaterThanOrEqualToThreshold
     * @stability stable
     */
    readonly comparisonOperator: cw.ComparisonOperator;
    /**
     * Sets how this alarm is to handle missing data points.
     *
     * @default TreatMissingData.Missing
     * @stability stable
     */
    readonly treatMissingData?: cw.TreatMissingData;
    /**
     * The number of periods over which data is compared to the specified threshold.
     *
     * @stability stable
     */
    readonly evaluationPeriods: number;
}
