import * as rds from '@aws-cdk/aws-rds';
import * as cdk from '@aws-cdk/core';
import { IWatchful } from './watchful';
/**
 * Options for defining alarms.
 *
 * @stability stable
 */
export interface WatchDatabaseClusterOptions {
    /**
     * Max CPU utilization threshold in percent.
     *
     * @default 80
     * @stability stable
     */
    readonly cpuUtilizationThreshold?: number;
    /**
     * Max freeable memory threshold in Byte.
     *
     * @default 64000000
     * @stability stable
     */
    readonly freeableMemoryThreshold?: number;
}
/**
 * Properties for defining a WatchDatabaseCluster.
 *
 * @stability stable
 */
export interface WatchDatabaseClusterProps extends WatchDatabaseClusterOptions {
    /**
     * The reference to IWatchful class.
     *
     * Used internally.
     *
     * @stability stable
     */
    readonly watchful: IWatchful;
    /**
     * The database cluster that should be watched.
     *
     * [disable-awslint:ref-via-interface]
     *
     * @stability stable
     */
    readonly databaseCluster: rds.DatabaseCluster;
}
/**
 * A Construct which creates the following alarms for database clusters:.
 *
 * - cpu utilization
 * - freeable memory
 *
 * @stability stable
 */
export declare class WatchDatabaseCluster extends cdk.Construct {
    private readonly watchful;
    private readonly rdsCluster;
    /**
     * @stability stable
     */
    constructor(scope: cdk.Construct, id: string, props: WatchDatabaseClusterProps);
    private createCPUUtilizationMonitor;
    private createFreeableMemoryMonitor;
}
