import * as elbv2 from '@aws-cdk/aws-elasticloadbalancingv2';
import * as cdk from '@aws-cdk/core';
import { IWatchful } from './watchful';
/**
 * Options for defining alarms.
 *
 * @stability stable
 */
export interface WatchApplicationTargetGroupOptions {
    /**
     * Number of allowed target connection errors per minute.
     *
     * @default 0
     * @stability stable
     */
    readonly targetConnectionErrorPerMinuteThreshold?: number;
    /**
     * Number of allowed HTTP 5xx requests per minute.
     *
     * @default 0
     * @stability stable
     */
    readonly http5xxPerMinuteThreshold?: number;
}
/**
 * Properties for defining a WatchApplicationTargetGroup.
 *
 * @stability stable
 */
export interface WatchApplicationTargetGroupProps extends WatchApplicationTargetGroupOptions {
    /**
     * The reference to IWatchful class.
     *
     * Used internally.
     *
     * @stability stable
     */
    readonly watchful: IWatchful;
    /**
     * The application target group that should be watched.
     *
     * [disable-awslint:ref-via-interface]
     *
     * @stability stable
     */
    readonly atg: elbv2.ApplicationTargetGroup;
}
/**
 * A Construct which creates the following alarms for application target groups:.
 *
 * - http-code 5xx
 * - target connection errors
 *
 * @stability stable
 */
export declare class WatchApplicationTargetGroup extends cdk.Construct {
    private readonly watchful;
    private readonly atg;
    /**
     * @stability stable
     */
    constructor(scope: cdk.Construct, id: string, props: WatchApplicationTargetGroupProps);
    private createTargetConnectionErrorMonitor;
    private createHttpCode5xxMonitor;
}
